@@ -439,6 +439,20 @@ Z39.50 record, assigned names that begin with underscores:
 
 =item C<_yearCaption>
 
+=item C<_accessionNumber>
+
+=item C<_copyNumber>
+
+=item C<_descriptionOfPieces>
+
+=item C<_discoverySuppress>
+
+=item C<_hrid>
+
+=item C<_id>
+
+=item C<_itemIdentifier>
+
 =back
 
 Since there may be multiple items in a single holding, sets of these
@@ -462,11 +476,12 @@ post-processing for JSON and XML records may also be supported.
 Within the C<marc> sections, keys are the names of simple MARC fields,
 such as C<008>; or of complex field$subfield combinations, such as
 C<245$a>. The corresponding values specify the transformations that
-should be applied to the values of these fields and subfields.
+should be applied to the values of these fields and subfields: each
+value may be either a single transformation or an array zero or more
+=transformation which will be applied in the specified order.
 
 Transformations are represented by objects with an C<op> key whose
-values specifies the required operation. Either single transformation
-or an array of transformations may be provided.
+values specifies the required operation.
 
 The following transformation operations are supported:
 
@@ -502,6 +517,35 @@ C<$2>, etc., to parenthesized sub-expressions in the pattern. (If this
 statement means nothing to you, you need to
 L<go and read about regular expressions|https://perldoc.perl.org/perlretut>.)
 
+Replacement strings may also include sequences of the form
+I<%{fieldname}>, where I<fieldname> is either a simple control-field
+tag such as C<001> or a field-and-subfield combination like
+C<245$a>. Such sequences cause the value of the specified field within
+the current record to be interpolated, so that for example a
+replacement string C<%{001}/%{245a}> will cause the text that matches
+the regular expression to be replaced by the contents of the C<001>
+and C<245$a> fields separated by a slash.
+
+This mechanism yields a powerful and general facility allowing
+installations with complex requirements to generate exactly the detail
+they need. For example, it can be used to implement fallbacks, as in
+this case where if C<952$2> has no value it's replaced by the value in
+C<952$b>. (This could be used for situations like reporting the
+item-level copy-number if that's present, but falling back to the
+holdings-level copy-number if not.)
+
+  "952$2": [
+    { "op": "regsub", "pattern": "^$", "replacement": "%{952$b}" }
+  ]
+
+Or a location string could be built in the C<$z> subfield from
+fragments in C<$1>, C<$2> and C<$2>:
+
+  "952$z": [
+    { "op": "regsub", "pattern": ".*", "replacement": "%{952$1}/%{952$2}/%{952$3}" }
+  ]
+
+
 =item C<flags>
 
 Optionally, a set of flags such as C<g> for global replacement, C<i>
