@@ -10,16 +10,21 @@ sub insertMARCHoldings {
     my $holdingsObjects = $rec->holdings($marc);
 
     for (my $i = 0; $i < @$holdingsObjects; $i++) {
-	my $holdingsMap = _listOfPairs2map($holdingsObjects->[$i]);
-
-	# Annoyingly, a field can't be created with no subfields, hence this "accumulator" approach
-	my $marcField = _addSubfields(undef, $marcCfg, $marcCfg->{holdingsElements}, $holdingsMap);
-
+        my $holdingsMap = _listOfPairs2map($holdingsObjects->[$i]);
 	my $itemObjects = $holdingsMap->{circulations};
-	for (my $j = 0; $j < @$itemObjects; $j++) {
-	    my $itemMap = _listOfPairs2map($itemObjects->[$j]);
-	    # use Data::Dumper; warn Dumper($itemMap);
-	    if (!$marcCfg->{restrictToItem} || !$barcode || $itemMap->{itemId} eq $barcode) {
+	my $marcField;
+	if ($marcCfg->{restrictToItem} && $barcode) {
+	    for (my $j = 0; $j < @$itemObjects; $j++) {
+		my $itemMap = _listOfPairs2map($itemObjects->[$j]);
+		if ($itemMap->{itemId} eq $barcode) {
+		    $marcField = _addSubfields(undef, $marcCfg, $marcCfg->{holdingsElements}, $holdingsMap);
+		    $marcField = _addSubfields($marcField, $marcCfg, $marcCfg->{itemElements}, $itemMap);
+		}
+	    }
+	} else {
+	    $marcField = _addSubfields(undef, $marcCfg, $marcCfg->{holdingsElements}, $holdingsMap);
+	    for (my $j = 0; $j < @$itemObjects; $j++) {
+		my $itemMap = _listOfPairs2map($itemObjects->[$j]);
 		$marcField = _addSubfields($marcField, $marcCfg, $marcCfg->{itemElements}, $itemMap);
 	    }
 	}
